==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebPivotDimensionDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotDimensionDescriptionMetadata } from "./WebPivotDimensionDescriptionMetadata";
import { WebFilteringExpressionsTreeDescriptionMetadata } from "./WebFilteringExpressionsTreeDescriptionMetadata";
import { WebPivotDimensionDetailDescription } from "./WebPivotDimensionDetailDescription";
/**
 * @hidden
 */
var WebPivotDimensionDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotDimensionDetailDescriptionMetadata, _super);
    function WebPivotDimensionDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPivotDimensionDetailDescriptionMetadata.b = function (a) {
        if (WebPivotDimensionDetailDescriptionMetadata.a == null) {
            WebPivotDimensionDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPivotDimensionDetailDescriptionMetadata.c(WebPivotDimensionDetailDescriptionMetadata.a);
        }
        if (a.j(WebPivotDimensionDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPivotDimensionDetailDescriptionMetadata.a);
        WebPivotDimensionDescriptionMetadata.d(a);
        WebFilteringExpressionsTreeDescriptionMetadata.d(a);
    };
    WebPivotDimensionDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PivotDimensionDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("ChildLevel", "ExportedType:WebPivotDimension");
        a.item("MemberName", "String");
        a.item("Enabled", "Boolean");
        a.item("Filter", "ExportedType:WebFilteringExpressionsTree");
        a.item("SortDirection", "ExportedType:string:SortingDirection");
        a.item("SortDirection@names", "None;Asc;Desc");
        a.item("DataType", "ExportedType:string:GridColumnDataType");
        a.item("DataType@names", "String;Number;Boolean;Date;DateTime;Time;Currency;Percent;Image");
        a.item("Width", "String");
        a.item("Level", "Number:double");
        a.item("MemberFunctionRef", "EventRef::memberFunction");
    };
    WebPivotDimensionDetailDescriptionMetadata.d = function (a) {
        WebPivotDimensionDetailDescriptionMetadata.b(a);
        a.aa("WebPivotDimensionDetail", function () { return new WebPivotDimensionDetailDescription(); });
        a.z("WebPivotDimensionDetail", WebPivotDimensionDetailDescriptionMetadata.a);
    };
    WebPivotDimensionDetailDescriptionMetadata.$t = markType(WebPivotDimensionDetailDescriptionMetadata, 'WebPivotDimensionDetailDescriptionMetadata');
    WebPivotDimensionDetailDescriptionMetadata.a = null;
    return WebPivotDimensionDetailDescriptionMetadata;
}(Base));
export { WebPivotDimensionDetailDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebPivotDimensionDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotDimensionDescriptionMetadata } from "./WebPivotDimensionDescriptionMetadata";
import { WebFilteringExpressionsTreeDescriptionMetadata } from "./WebFilteringExpressionsTreeDescriptionMetadata";
import { WebPivotDimensionDetailDescription } from "./WebPivotDimensionDetailDescription";
/**
 * @hidden
 */
var WebPivotDimensionDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotDimensionDetailDescriptionMetadata, _super);
    function WebPivotDimensionDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPivotDimensionDetailDescriptionMetadata.b = function (a) {
        if (WebPivotDimensionDetailDescriptionMetadata.a == null) {
            WebPivotDimensionDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPivotDimensionDetailDescriptionMetadata.c(WebPivotDimensionDetailDescriptionMetadata.a);
        }
        if (a.k(WebPivotDimensionDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPivotDimensionDetailDescriptionMetadata.a);
        WebPivotDimensionDescriptionMetadata.d(a);
        WebFilteringExpressionsTreeDescriptionMetadata.d(a);
    };
    WebPivotDimensionDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PivotDimensionDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("ChildLevel", "ExportedType:WebPivotDimension");
        a.item("MemberName", "String");
        a.item("Enabled", "Boolean");
        a.item("Filter", "ExportedType:WebFilteringExpressionsTree");
        a.item("SortDirection", "ExportedType:string:SortingDirection");
        a.item("SortDirection@names", "None;Asc;Desc");
        a.item("DataType", "ExportedType:string:GridColumnDataType");
        a.item("DataType@stringUnion", "WebComponents;React");
        a.item("DataType@names", "String;Number;Boolean;Date;DateTime;Time;Currency;Percent;Image");
        a.item("Width", "String");
        a.item("Level", "Number:double");
        a.item("MemberFunctionRef", "EventRef::memberFunction");
    };
    WebPivotDimensionDetailDescriptionMetadata.d = function (a) {
        WebPivotDimensionDetailDescriptionMetadata.b(a);
        a.ac("WebPivotDimensionDetail", function () { return new WebPivotDimensionDetailDescription(); });
        a.ab("WebPivotDimensionDetail", WebPivotDimensionDetailDescriptionMetadata.a);
    };
    WebPivotDimensionDetailDescriptionMetadata.$t = markType(WebPivotDimensionDetailDescriptionMetadata, 'WebPivotDimensionDetailDescriptionMetadata');
    WebPivotDimensionDetailDescriptionMetadata.a = null;
    return WebPivotDimensionDetailDescriptionMetadata;
}(Base));
export { WebPivotDimensionDetailDescriptionMetadata };
